@@ -5,7 +5,7 @@ package Net::SNTP::Client;
 BEGIN { die 'Perl version 5.6.0 or greater is required' if ($] < 5.006); }
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 
 =head1 NAME
 
@@ -15,13 +15,13 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 $VERSION = eval $VERSION;
 
 ## Load our modules
@@ -55,7 +55,6 @@ The module sends a UDP packet formated according to
  to a human readable form and also calculated the roundtrip delay 
  d and system clock offset t, based on the decoded data.
 
-
 =head1 DESCRIPTION
 
 This module exports a single method (getSNTPTime) and returns
@@ -101,7 +100,6 @@ This module exports a single method (getSNTPTime) and returns
 
   my ( $error , $hashRefOutput ) = getSNTPTime( %hashInput );
 
-
 =cut
 
 ## Define constands
@@ -155,22 +153,6 @@ sub getSNTPTime {
     };
     return ($error = "Problem While Creating Socket '$!'", \%moduleInput) if ( $@ && $@ =~ /Error Creating Socket/ );
 
-    # LI_VN_Mode                    => '00100011' # 8 bit
-    # Stratum                       => '0'        # 8 bit
-    # Poll                          => '0'        # 8 bit
-    # Precision                     => '0'        # 8 bit
-    # Root_Delay                    => '0'        # 32 bit
-    # Root_Dispersion               => '0'        # 32 bit
-    # Reference_Identifier          => '0'        # 32 bit
-    # Reference_Timestamp_Sec       => '0'        # 32 bit
-    # Reference_Timestamp_Micro_Sec => '0'        # 32 bit
-    # Originate_Timestamp_Sec       => '0'        # 32 bit
-    # Originate_Timestamp_Micro_Sec => '0'        # 32 bit
-    # Receive_Timestamp_Sec         => '0'        # 32 bit
-    # Receive_Timestamp_Micro_Sec   => '0'        # 32 bit
-    # Transmit_Timestamp_Sec        => '0'        # 32 bit
-    # Transmit_Timestamp_Micro_Sec  => '0'        # 32 bit
-
     my %SNTP_Client_Hash = (
 	"LI"                            => 0,
 	"VN"                            => 4,
@@ -233,6 +215,7 @@ sub getSNTPTime {
 
     if ( $@ && $@ =~ /Error Receiving/ ){
 	return ($error = "Problem While Receiving '$!'", \%moduleInput);
+
     }
     elsif ($@ && $@ =~ /Error Timeout/) {
 	return ($error = "Net::SNTP::Client timed out waiting the packet '$!'", \%moduleInput);
@@ -247,7 +230,7 @@ sub getSNTPTime {
     return ($error = "Problem While Clossing Socket '$!'", \%moduleInput) if ( $@ && $@ =~ /Error Closing Socket/ );
 
     my %RcV;
-    @RcV{@SNTP_Receive} = unpack("B8 C3 s B16 n B16 H8 N8" , $rcvSntpPacket);
+    @RcV{@SNTP_Receive} = unpack("B8 C3 s n3 H8 N8" , $rcvSntpPacket);
 
     $RcV{"LI Binary"} = substr( $RcV{"LI VN Mode"} , 0 , 2 );
     $RcV{"LI"} = _binaryToDecimal( $RcV{"LI Binary"} , 8 , "c" );
@@ -264,27 +247,21 @@ sub getSNTPTime {
 
     $RcV{"Poll"} = (sprintf("%.1d", $RcV{"Poll"}));
 
-    if ($RcV{"Precision"} < 127) {
-	$RcV{"Precision"} = 0;
-    }
-    else {
+    if ($RcV{"Precision"} > 127) {
 	$RcV{"Precision"} = $RcV{"Precision"} - 255;
     }
-
-    $RcV{"Root Delay"} = 
-	_binaryToDecimal( $RcV{"Root Delay"} , 16 , "s" );
+    else {
+	$RcV{"Precision"} = "-" . $RcV{"Precision"};
+    }
 
     $RcV{"Root Delay Fraction"} = 
-	_binaryToDecimal( $RcV{"Root Delay Fraction"} , 16 , "n" );
+	sprintf("%05d", $RcV{"Root Delay Fraction"});
     
     $RcV{"Root Delay"} = 
-	$RcV{"Root Delay"} . "." . $RcV{"Root Delay Fraction"};
+	$RcV{"Root Delay"} . "." . $RcV{"Root Delay Fraction"};    
 
-    $RcV{"Root Dispersion"} = 
-	_binaryToDecimal( $RcV{"Root Dispersion"} , 16 , "n" );
-
-    $RcV{"Root Dispersion Fraction"} = 
-	_binaryToDecimal( $RcV{"Root Dispersion Fraction"} , 16 , "n" );
+    $RcV{"Root Dispersion Fraction"} =
+	sprintf("%05d", $RcV{"Root Dispersion Fraction"});
     
     $RcV{"Root Dispersion"} = 
 	$RcV{"Root Dispersion"} . "." . $RcV{"Root Dispersion Fraction"};
@@ -624,10 +601,8 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 13.0  2015/07/26 2:34:31 pm  Thanos
-
+Revision 14.0  2015/07/31 12:34:31 am  Thanos
 
 =cut
 
 1; # End of Net::SNTP::Client
-
